@@ -13,6 +13,8 @@ from .base import Measure, BaseMeasure, ParamInfo, MultiMeasures, MeanAgg, SumAg
 from .ap import AP, MAP, _AP
 from .bpm import BPM, _BPM
 from .bpref import Bpref, BPref, _Bpref
+from .compat import Compat, _Compat
+from .diversity import ERR_IA, _ERR_IA, nERR_IA, _nERR_IA, alpha_DCG, α_DCG, _alpha_DCG, alpha_nDCG, α_nDCG, _alpha_nDCG, NRBP, _NRBP, nNRBP, _nNRBP, AP_IA, MAP_IA, _AP_IA, P_IA, _P_IA, StRecall, _StRecall
 from .err import ERR, _ERR
 from .inst import INST, _INST, INSQ, _INSQ
 from .infap import infAP, _infAP
