@@ -9,7 +9,18 @@ class _AP(measures.Measure):
     
     AP is typically used for adhoc ranking tasks where getting as many relevant items as possible is. It is commonly referred to as MAP,
     by taking the mean of AP over the query set.
-    
+
+::
+
+    @article{Harman:1992:ESIR,
+      author = {Donna Harman},
+      title = {Evaluation Issues in Information Retrieval},
+      journal = {Information Processing and Management},
+      volume = {28},
+      number = {4},
+      pages = {439 - -440},
+      year = {1992},
+    }
     """
     __name__ = 'AP'
     NAME = __name__
