@@ -6,6 +6,15 @@ class _Bpref(measures.Measure):
     """
     Binary Preference (Bpref).
     This measure examines the relative ranks of judged relevant and non-relevant documents. Non-judged documents are not considered. 
+
+::
+
+    @inproceedings{Buckley2004RetrievalEW,
+      title={Retrieval evaluation with incomplete information},
+      author={Chris Buckley and Ellen M. Voorhees},
+      booktitle={SIGIR},
+      year={2004}
+    }
     """
     __name__ = 'Bpref'
     NAME = __name__
