@@ -1,28 +1,28 @@
 import sys
 import contextlib
 import functools
-import pandas as pd
 import ir_measures
-from ir_measures import providers, measures
-from ir_measures.providers.base import Any, Choices, Metric, NOT_PROVIDED
+from ir_measures import providers, measures, Metric
+from ir_measures.providers.base import Any, Choices, NOT_PROVIDED
 
 
-class TrectoolsProvider(providers.MeasureProvider):
+class TrectoolsProvider(providers.Provider):
     """
     trectools
 
     https://github.com/joaopalotti/trectools
 
-```
-@inproceedings{palotti2019,
- author = {Palotti, Joao and Scells, Harrisen and Zuccon, Guido},
- title = {TrecTools: an open-source Python library for Information Retrieval practitioners involved in TREC-like campaigns},
- series = {SIGIR'19},
- year = {2019},
- location = {Paris, France},
- publisher = {ACM}
-}
-```
+::
+
+    @inproceedings{palotti2019,
+       author = {Palotti, Joao and Scells, Harrisen and Zuccon, Guido},
+       title = {TrecTools: an open-source Python library for Information Retrieval practitioners involved in TREC-like campaigns},
+       series = {SIGIR'19},
+       year = {2019},
+       location = {Paris, France},
+       publisher = {ACM}
+    }
+
     """
     NAME = 'trectools'
     SUPPORTED_MEASURES = [
@@ -40,36 +40,26 @@ class TrectoolsProvider(providers.MeasureProvider):
         super().__init__()
         self.trectools = None
 
-    @contextlib.contextmanager
-    def _calc_ctxt(self, measures, qrels):
+    def _evaluator(self, measures, qrels):
+        import pandas as pd
+        measures = ir_measures.util.flatten_measures(measures)
         # Convert qrels to dict_of_dict (input format used by pytrec_eval)
         tmp_qrels = ir_measures.util.QrelsConverter(qrels).as_namedtuple_iter()
         tmp_qrels = pd.DataFrame(tmp_qrels)
-        tmp_qrels = tmp_qrels.rename(columns={'query_id': 'query', 'doc_id': 'docid', 'relevance': 'rel'})
+        if len(tmp_qrels) == 0:
+            tmp_qrels = pd.DataFrame(columns=['query', 'docid', 'rel'], dtype='object')
+        else:
+            tmp_qrels = tmp_qrels.rename(columns={'query_id': 'query', 'doc_id': 'docid', 'relevance': 'rel'})
         qrels = self.trectools.TrecQrel()
         qrels.qrels_data = tmp_qrels
 
-        invocations = self._build_invocations(measures, qrels)
+        invocations = self._build_invocations(measures)
 
-        def _iter_calc(run):
-            # Convert qrels to dict_of_dict (input format used by pytrec_eval)
-            tmp_run = ir_measures.util.RunConverter(run).as_namedtuple_iter()
-            tmp_run = pd.DataFrame(tmp_run)
-            tmp_run = tmp_run.rename(columns={'query_id': 'query', 'doc_id': 'docid', 'score': 'score'})
-            tmp_run.sort_values(['query', 'score'], ascending=[True, False], inplace=True)
-            run = self.trectools.TrecRun()
-            run.run_data = tmp_run
-            evaluator = self.trectools.TrecEval(run, qrels)
-            for invocation, measure in invocations:
-                print(measure)
-                for query_id, value in invocation(evaluator).itertuples():
-                    yield Metric(query_id=query_id, measure=measure, value=value)
+        return TrectoolsEvaluator(measures, qrels, invocations, self.trectools)
 
-        yield _iter_calc
-
-    def _build_invocations(self, measures, qrels):
+    def _build_invocations(self, measures):
         invocations = []
-        for measure in ir_measures.util.flatten_measures(measures):
+        for measure in measures:
             def depth():
                 try:
                     cutoff = measure['cutoff']
@@ -120,4 +110,31 @@ class TrectoolsProvider(providers.MeasureProvider):
             raise RuntimeError('trectools not available', ex)
 
 
+class TrectoolsEvaluator(providers.Evaluator):
+    def __init__(self, measures, qrels, invocations, trectools):
+        super().__init__(measures, qrels.qrels_data['query'].unique())
+        self.qrels = qrels
+        self.invocations = invocations
+        self.trectools = trectools
+
+    def _iter_calc(self, run):
+        import pandas as pd
+        available_qids = set(self.qrels.qrels_data['query'].unique())
+        tmp_run = ir_measures.util.RunConverter(run).as_namedtuple_iter()
+        tmp_run = pd.DataFrame(tmp_run)
+        if len(tmp_run) == 0:
+            tmp_run = pd.DataFrame(columns=['query', 'docid', 'score'], dtype='object')
+        else:
+            tmp_run = tmp_run.rename(columns={'query_id': 'query', 'doc_id': 'docid', 'score': 'score'})
+        tmp_run.sort_values(['query', 'score'], ascending=[True, False], inplace=True)
+        run = self.trectools.TrecRun()
+        run.run_data = tmp_run
+        evaluator = self.trectools.TrecEval(run, self.qrels)
+        for invocation, measure in self.invocations:
+            for query_id, value in invocation(evaluator).itertuples():
+                if query_id in available_qids:
+                    yield Metric(query_id=query_id, measure=measure, value=value)
+
+
+
 providers.register(TrectoolsProvider())
